==> qianmi-rnapp-updater-0.0.59.tgz: package/ios/Sources/RNRenderBuilder.m <==
//
//  RNRenderExtend.m
//  rl
//
//  Created by 夏迎霖 on 2017/9/25.
//  Copyright © 2017年 Facebook. All rights reserved.
//

#import "RNRenderBuilder.h"
#import <React/RCTBundleURLProvider.h>


static NSString * const RNRenderStorageKey = @"rn_render_storage_key";
static NSString * const KeyBundleUri = @"bundle_url";
static NSString * const KeyBundleVersion = @"bundle_version";
static NSString * const KeyAppURL = @"app_url";



@interface RNRenderBuilder() <RCTBridgeDelegate>


@end


@implementation RNRenderBuilder

- (NSURL *)sourceURLForBridge:(RCTBridge *)bridge {
    NSString *storageDirectory = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES).firstObject;
    storageDirectory = [storageDirectory stringByAppendingPathComponent: @"RCTAsyncLocalStorage_V1"];
    storageDirectory = [storageDirectory stringByAppendingPathComponent: @"manifest.json"];
    NSData* data = [NSData dataWithContentsOfFile: storageDirectory];
    if(data) {
        NSDictionary* dic = [NSJSONSerialization JSONObjectWithData: data options:NSJSONReadingMutableContainers error: nil];
        NSData* d = [dic[RNRenderStorageKey]  dataUsingEncoding: NSUTF8StringEncoding];
        NSDictionary* obj = [NSJSONSerialization JSONObjectWithData: d options:NSJSONReadingMutableContainers error: nil];
        NSString* uri = obj[KeyBundleUri];
        if(uri){
            if([uri hasSuffix: @".html"]) {
                if([UIDevice currentDevice].systemVersion.doubleValue >= 10){
                    [[UIApplication sharedApplication] openURL: [NSURL URLWithString:uri] options: @{} completionHandler:nil];
                }else {
                    [[UIApplication sharedApplication] openURL: [NSURL URLWithString:uri]];
                }
                return [[RCTBundleURLProvider sharedSettings] jsBundleURLForBundleRoot:@"index.ios" fallbackResource:nil];
            }
            
            return [NSURL fileURLWithPath: uri];
        }
    }
    return [[RCTBundleURLProvider sharedSettings] jsBundleURLForBundleRoot:@"index.ios" fallbackResource:nil];
}


- (RCTRootView*) view: (NSDictionary *)launchOptions moduleName: (NSString*) moduleName {
    RCTBridge* bridge = [[RCTBridge alloc] initWithDelegate: self launchOptions: launchOptions];
    return [[RCTRootView alloc] initWithBridge:bridge moduleName:moduleName initialProperties: nil];
}

@end

==> qianmi-rnapp-updater-0.0.60.tgz: package/ios/Sources/RNRenderBuilder.m <==
//
//  RNRenderExtend.m
//  rl
//
//  Created by 夏迎霖 on 2017/9/25.
//  Copyright © 2017年 Facebook. All rights reserved.
//

#import "RNRenderBuilder.h"
#import <React/RCTBundleURLProvider.h>


static NSString * const KeyAppURL = @"app_file";
static NSString * const KeyBundleUri = @"bundle_file";
static NSString * const KeyBundleVersion = @"bundle_version";



@interface RNRenderBuilder() <RCTBridgeDelegate>
@end

@implementation RNRenderBuilder

- (NSURL *)sourceURLForBridge:(RCTBridge *)bridge {
//    NSString *storageDirectory = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES).firstObject;
//    storageDirectory = [storageDirectory stringByAppendingPathComponent: @"RCTAsyncLocalStorage_V1"];
//    storageDirectory = [storageDirectory stringByAppendingPathComponent: @"manifest.json"];
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSData* data = [NSData dataWithContentsOfFile: [[paths firstObject] stringByAppendingString:@"version.json" ]];
    
    if(data) {
        NSDictionary* dic = [NSJSONSerialization JSONObjectWithData: data options:NSJSONReadingMutableContainers error: nil];
        NSString* uri = dic[KeyBundleUri];
        if(uri){
            if([uri hasSuffix: @".html"]) {
                if([UIDevice currentDevice].systemVersion.doubleValue >= 10){
                    [[UIApplication sharedApplication] openURL: [NSURL URLWithString:uri] options: @{} completionHandler:nil];
                }else {
                    [[UIApplication sharedApplication] openURL: [NSURL URLWithString:uri]];
                }
                return [[RCTBundleURLProvider sharedSettings] jsBundleURLForBundleRoot:@"index.ios" fallbackResource:nil];
            }
            
            return [NSURL fileURLWithPath: uri];
        }
    }
    return [[RCTBundleURLProvider sharedSettings] jsBundleURLForBundleRoot:@"index.ios" fallbackResource:nil];
}


- (RCTRootView*) view: (NSDictionary *)launchOptions moduleName: (NSString*) moduleName {
    RCTBridge* bridge = [[RCTBridge alloc] initWithDelegate: self launchOptions: launchOptions];
    return [[RCTRootView alloc] initWithBridge:bridge moduleName:moduleName initialProperties: nil];
}

@end
